Class: Google::Apis::WorkstationsV1::CloudWorkstationsService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::WorkstationsV1::CloudWorkstationsService
- Defined in:
- lib/google/apis/workstations_v1/service.rb
Overview
Cloud Workstations API
Allows administrators to create managed developer environments in the cloud.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://workstations.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::GoogleProtobufEmpty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_workstation_cluster(parent, workstation_cluster_object = nil, validate_only: nil, workstation_cluster_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Creates a new workstation cluster.
-
#create_project_location_workstation_cluster_workstation_config(parent, workstation_config_object = nil, validate_only: nil, workstation_config_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Creates a new workstation configuration.
-
#create_project_location_workstation_cluster_workstation_config_workstation(parent, workstation_object = nil, validate_only: nil, workstation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Creates a new workstation.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::GoogleProtobufEmpty
Deletes a long-running operation.
-
#delete_project_location_workstation_cluster(name, etag: nil, force: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Deletes the specified workstation cluster.
-
#delete_project_location_workstation_cluster_workstation_config(name, etag: nil, force: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Deletes the specified workstation configuration.
-
#delete_project_location_workstation_cluster_workstation_config_workstation(name, etag: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Deletes the specified workstation.
-
#generate_workstation_access_token(workstation, generate_access_token_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::GenerateAccessTokenResponse
Returns a short-lived credential that can be used to send authenticated and authorized traffic to a workstation.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Location
Gets information about a location.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_workstation_cluster(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::WorkstationCluster
Returns the requested workstation cluster.
-
#get_project_location_workstation_cluster_workstation_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::WorkstationConfig
Returns the requested workstation configuration.
-
#get_project_location_workstation_cluster_workstation_config_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Policy
Gets the access control policy for a resource.
-
#get_project_location_workstation_cluster_workstation_config_workstation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Workstation
Returns the requested workstation.
-
#get_project_location_workstation_cluster_workstation_config_workstation_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Policy
Gets the access control policy for a resource.
-
#initialize ⇒ CloudWorkstationsService
constructor
A new instance of CloudWorkstationsService.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_workstation_cluster_workstation_config_usable(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::ListUsableWorkstationConfigsResponse
Returns all workstation configurations in the specified cluster on which the caller has the "workstations.workstation.create" permission.
-
#list_project_location_workstation_cluster_workstation_config_workstation_usable(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::ListUsableWorkstationsResponse
Returns all workstations using the specified workstation configuration on which the caller has the "workstations.workstations.use" permission.
-
#list_project_location_workstation_cluster_workstation_config_workstations(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::ListWorkstationsResponse
Returns all Workstations using the specified workstation configuration.
-
#list_project_location_workstation_cluster_workstation_configs(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::ListWorkstationConfigsResponse
Returns all workstation configurations in the specified cluster.
-
#list_project_location_workstation_clusters(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::ListWorkstationClustersResponse
Returns all workstation clusters in the specified location.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_workstation_cluster(name, workstation_cluster_object = nil, allow_missing: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Updates an existing workstation cluster.
-
#patch_project_location_workstation_cluster_workstation_config(name, workstation_config_object = nil, allow_missing: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Updates an existing workstation configuration.
-
#patch_project_location_workstation_cluster_workstation_config_workstation(name, workstation_object = nil, allow_missing: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Updates an existing workstation.
-
#set_workstation_config_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Policy
Sets the access control policy on the specified resource.
-
#set_workstation_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Policy
Sets the access control policy on the specified resource.
-
#start_workstation(name, start_workstation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Starts running a workstation so that users can connect to it.
-
#stop_workstation(name, stop_workstation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Stops running a workstation, reducing costs.
-
#test_workstation_config_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#test_workstation_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
Constructor Details
#initialize ⇒ CloudWorkstationsService
Returns a new instance of CloudWorkstationsService.
47 48 49 50 51 52 |
# File 'lib/google/apis/workstations_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-workstations_v1', client_version: Google::Apis::WorkstationsV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/workstations_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/workstations_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::GoogleProtobufEmpty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/google/apis/workstations_v1/service.rb', line 168 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::WorkstationsV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::WorkstationsV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::WorkstationsV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_workstation_cluster(parent, workstation_cluster_object = nil, validate_only: nil, workstation_cluster_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Creates a new workstation cluster.
319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/google/apis/workstations_v1/service.rb', line 319 def create_project_location_workstation_cluster(parent, workstation_cluster_object = nil, validate_only: nil, workstation_cluster_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/workstationClusters', ) command.request_representation = Google::Apis::WorkstationsV1::WorkstationCluster::Representation command.request_object = workstation_cluster_object command.response_representation = Google::Apis::WorkstationsV1::Operation::Representation command.response_class = Google::Apis::WorkstationsV1::Operation command.params['parent'] = parent unless parent.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['workstationClusterId'] = workstation_cluster_id unless workstation_cluster_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_workstation_cluster_workstation_config(parent, workstation_config_object = nil, validate_only: nil, workstation_config_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Creates a new workstation configuration.
517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'lib/google/apis/workstations_v1/service.rb', line 517 def create_project_location_workstation_cluster_workstation_config(parent, workstation_config_object = nil, validate_only: nil, workstation_config_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/workstationConfigs', ) command.request_representation = Google::Apis::WorkstationsV1::WorkstationConfig::Representation command.request_object = workstation_config_object command.response_representation = Google::Apis::WorkstationsV1::Operation::Representation command.response_class = Google::Apis::WorkstationsV1::Operation command.params['parent'] = parent unless parent.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['workstationConfigId'] = workstation_config_id unless workstation_config_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_workstation_cluster_workstation_config_workstation(parent, workstation_object = nil, validate_only: nil, workstation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Creates a new workstation.
874 875 876 877 878 879 880 881 882 883 884 885 886 |
# File 'lib/google/apis/workstations_v1/service.rb', line 874 def create_project_location_workstation_cluster_workstation_config_workstation(parent, workstation_object = nil, validate_only: nil, workstation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/workstations', ) command.request_representation = Google::Apis::WorkstationsV1::Workstation::Representation command.request_object = workstation_object command.response_representation = Google::Apis::WorkstationsV1::Operation::Representation command.response_class = Google::Apis::WorkstationsV1::Operation command.params['parent'] = parent unless parent.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['workstationId'] = workstation_id unless workstation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::GoogleProtobufEmpty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
203 204 205 206 207 208 209 210 211 |
# File 'lib/google/apis/workstations_v1/service.rb', line 203 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkstationsV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::WorkstationsV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_workstation_cluster(name, etag: nil, force: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Deletes the specified workstation cluster.
363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/google/apis/workstations_v1/service.rb', line 363 def delete_project_location_workstation_cluster(name, etag: nil, force: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkstationsV1::Operation::Representation command.response_class = Google::Apis::WorkstationsV1::Operation command.params['name'] = name unless name.nil? command.query['etag'] = etag unless etag.nil? command.query['force'] = force unless force.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_workstation_cluster_workstation_config(name, etag: nil, force: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Deletes the specified workstation configuration.
561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'lib/google/apis/workstations_v1/service.rb', line 561 def delete_project_location_workstation_cluster_workstation_config(name, etag: nil, force: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkstationsV1::Operation::Representation command.response_class = Google::Apis::WorkstationsV1::Operation command.params['name'] = name unless name.nil? command.query['etag'] = etag unless etag.nil? command.query['force'] = force unless force.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_workstation_cluster_workstation_config_workstation(name, etag: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Deletes the specified workstation.
914 915 916 917 918 919 920 921 922 923 924 |
# File 'lib/google/apis/workstations_v1/service.rb', line 914 def delete_project_location_workstation_cluster_workstation_config_workstation(name, etag: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkstationsV1::Operation::Representation command.response_class = Google::Apis::WorkstationsV1::Operation command.params['name'] = name unless name.nil? command.query['etag'] = etag unless etag.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_workstation_access_token(workstation, generate_access_token_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::GenerateAccessTokenResponse
Returns a short-lived credential that can be used to send authenticated and authorized traffic to a workstation. Once generated this token cannot be revoked and is good for the lifetime of the token.
950 951 952 953 954 955 956 957 958 959 960 |
# File 'lib/google/apis/workstations_v1/service.rb', line 950 def generate_workstation_access_token(workstation, generate_access_token_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+workstation}:generateAccessToken', ) command.request_representation = Google::Apis::WorkstationsV1::GenerateAccessTokenRequest::Representation command.request_object = generate_access_token_request_object command.response_representation = Google::Apis::WorkstationsV1::GenerateAccessTokenResponse::Representation command.response_class = Google::Apis::WorkstationsV1::GenerateAccessTokenResponse command.params['workstation'] = workstation unless workstation.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/workstations_v1/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkstationsV1::Location::Representation command.response_class = Google::Apis::WorkstationsV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
234 235 236 237 238 239 240 241 242 |
# File 'lib/google/apis/workstations_v1/service.rb', line 234 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkstationsV1::Operation::Representation command.response_class = Google::Apis::WorkstationsV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_workstation_cluster(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::WorkstationCluster
Returns the requested workstation cluster.
396 397 398 399 400 401 402 403 404 |
# File 'lib/google/apis/workstations_v1/service.rb', line 396 def get_project_location_workstation_cluster(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkstationsV1::WorkstationCluster::Representation command.response_class = Google::Apis::WorkstationsV1::WorkstationCluster command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_workstation_cluster_workstation_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::WorkstationConfig
Returns the requested workstation configuration.
594 595 596 597 598 599 600 601 602 |
# File 'lib/google/apis/workstations_v1/service.rb', line 594 def get_project_location_workstation_cluster_workstation_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkstationsV1::WorkstationConfig::Representation command.response_class = Google::Apis::WorkstationsV1::WorkstationConfig command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_workstation_cluster_workstation_config_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
638 639 640 641 642 643 644 645 646 647 |
# File 'lib/google/apis/workstations_v1/service.rb', line 638 def get_project_location_workstation_cluster_workstation_config_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::WorkstationsV1::Policy::Representation command.response_class = Google::Apis::WorkstationsV1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_workstation_cluster_workstation_config_workstation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Workstation
Returns the requested workstation.
982 983 984 985 986 987 988 989 990 |
# File 'lib/google/apis/workstations_v1/service.rb', line 982 def get_project_location_workstation_cluster_workstation_config_workstation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::WorkstationsV1::Workstation::Representation command.response_class = Google::Apis::WorkstationsV1::Workstation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_workstation_cluster_workstation_config_workstation_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/google/apis/workstations_v1/service.rb', line 1026 def get_project_location_workstation_cluster_workstation_config_workstation_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::WorkstationsV1::Policy::Representation command.response_class = Google::Apis::WorkstationsV1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/google/apis/workstations_v1/service.rb', line 279 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::WorkstationsV1::ListOperationsResponse::Representation command.response_class = Google::Apis::WorkstationsV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_workstation_cluster_workstation_config_usable(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::ListUsableWorkstationConfigsResponse
Returns all workstation configurations in the specified cluster on which the caller has the "workstations.workstation.create" permission.
714 715 716 717 718 719 720 721 722 723 724 |
# File 'lib/google/apis/workstations_v1/service.rb', line 714 def list_project_location_workstation_cluster_workstation_config_usable(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/workstationConfigs:listUsable', ) command.response_representation = Google::Apis::WorkstationsV1::ListUsableWorkstationConfigsResponse::Representation command.response_class = Google::Apis::WorkstationsV1::ListUsableWorkstationConfigsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_workstation_cluster_workstation_config_workstation_usable(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::ListUsableWorkstationsResponse
Returns all workstations using the specified workstation configuration on which the caller has the "workstations.workstations.use" permission.
1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 |
# File 'lib/google/apis/workstations_v1/service.rb', line 1102 def list_project_location_workstation_cluster_workstation_config_workstation_usable(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/workstations:listUsable', ) command.response_representation = Google::Apis::WorkstationsV1::ListUsableWorkstationsResponse::Representation command.response_class = Google::Apis::WorkstationsV1::ListUsableWorkstationsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_workstation_cluster_workstation_config_workstations(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::ListWorkstationsResponse
Returns all Workstations using the specified workstation configuration.
1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 |
# File 'lib/google/apis/workstations_v1/service.rb', line 1064 def list_project_location_workstation_cluster_workstation_config_workstations(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/workstations', ) command.response_representation = Google::Apis::WorkstationsV1::ListWorkstationsResponse::Representation command.response_class = Google::Apis::WorkstationsV1::ListWorkstationsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_workstation_cluster_workstation_configs(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::ListWorkstationConfigsResponse
Returns all workstation configurations in the specified cluster.
676 677 678 679 680 681 682 683 684 685 686 687 |
# File 'lib/google/apis/workstations_v1/service.rb', line 676 def list_project_location_workstation_cluster_workstation_configs(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/workstationConfigs', ) command.response_representation = Google::Apis::WorkstationsV1::ListWorkstationConfigsResponse::Representation command.response_class = Google::Apis::WorkstationsV1::ListWorkstationConfigsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_workstation_clusters(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::ListWorkstationClustersResponse
Returns all workstation clusters in the specified location.
433 434 435 436 437 438 439 440 441 442 443 444 |
# File 'lib/google/apis/workstations_v1/service.rb', line 433 def list_project_location_workstation_clusters(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/workstationClusters', ) command.response_representation = Google::Apis::WorkstationsV1::ListWorkstationClustersResponse::Representation command.response_class = Google::Apis::WorkstationsV1::ListWorkstationClustersResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/google/apis/workstations_v1/service.rb', line 126 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::WorkstationsV1::ListLocationsResponse::Representation command.response_class = Google::Apis::WorkstationsV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_workstation_cluster(name, workstation_cluster_object = nil, allow_missing: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Updates an existing workstation cluster.
476 477 478 479 480 481 482 483 484 485 486 487 488 489 |
# File 'lib/google/apis/workstations_v1/service.rb', line 476 def patch_project_location_workstation_cluster(name, workstation_cluster_object = nil, allow_missing: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::WorkstationsV1::WorkstationCluster::Representation command.request_object = workstation_cluster_object command.response_representation = Google::Apis::WorkstationsV1::Operation::Representation command.response_class = Google::Apis::WorkstationsV1::Operation command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_workstation_cluster_workstation_config(name, workstation_config_object = nil, allow_missing: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Updates an existing workstation configuration.
757 758 759 760 761 762 763 764 765 766 767 768 769 770 |
# File 'lib/google/apis/workstations_v1/service.rb', line 757 def patch_project_location_workstation_cluster_workstation_config(name, workstation_config_object = nil, allow_missing: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::WorkstationsV1::WorkstationConfig::Representation command.request_object = workstation_config_object command.response_representation = Google::Apis::WorkstationsV1::Operation::Representation command.response_class = Google::Apis::WorkstationsV1::Operation command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_workstation_cluster_workstation_config_workstation(name, workstation_object = nil, allow_missing: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Updates an existing workstation.
1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 |
# File 'lib/google/apis/workstations_v1/service.rb', line 1143 def patch_project_location_workstation_cluster_workstation_config_workstation(name, workstation_object = nil, allow_missing: nil, update_mask: nil, validate_only: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::WorkstationsV1::Workstation::Representation command.request_object = workstation_object command.response_representation = Google::Apis::WorkstationsV1::Operation::Representation command.response_class = Google::Apis::WorkstationsV1::Operation command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['validateOnly'] = validate_only unless validate_only.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_workstation_config_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
797 798 799 800 801 802 803 804 805 806 807 |
# File 'lib/google/apis/workstations_v1/service.rb', line 797 def set_workstation_config_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::WorkstationsV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::WorkstationsV1::Policy::Representation command.response_class = Google::Apis::WorkstationsV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_workstation_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 |
# File 'lib/google/apis/workstations_v1/service.rb', line 1183 def set_workstation_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::WorkstationsV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::WorkstationsV1::Policy::Representation command.response_class = Google::Apis::WorkstationsV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#start_workstation(name, start_workstation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Starts running a workstation so that users can connect to it.
1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 |
# File 'lib/google/apis/workstations_v1/service.rb', line 1216 def start_workstation(name, start_workstation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:start', ) command.request_representation = Google::Apis::WorkstationsV1::StartWorkstationRequest::Representation command.request_object = start_workstation_request_object command.response_representation = Google::Apis::WorkstationsV1::Operation::Representation command.response_class = Google::Apis::WorkstationsV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#stop_workstation(name, stop_workstation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::Operation
Stops running a workstation, reducing costs.
1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 |
# File 'lib/google/apis/workstations_v1/service.rb', line 1249 def stop_workstation(name, stop_workstation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:stop', ) command.request_representation = Google::Apis::WorkstationsV1::StopWorkstationRequest::Representation command.request_object = stop_workstation_request_object command.response_representation = Google::Apis::WorkstationsV1::Operation::Representation command.response_class = Google::Apis::WorkstationsV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_workstation_config_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
836 837 838 839 840 841 842 843 844 845 846 |
# File 'lib/google/apis/workstations_v1/service.rb', line 836 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::WorkstationsV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::WorkstationsV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::WorkstationsV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_workstation_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::WorkstationsV1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 |
# File 'lib/google/apis/workstations_v1/service.rb', line 1288 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::WorkstationsV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::WorkstationsV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::WorkstationsV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |