Class: Google::Apis::WorkstationsV1::GceHyperdiskBalancedHighAvailability

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1/classes.rb,
lib/google/apis/workstations_v1/representations.rb,
lib/google/apis/workstations_v1/representations.rb

Overview

A Persistent Directory backed by a Compute Engine Hyperdisk Balanced High Availability Disk. This is a high-availability block storage solution that offers a balance between performance and cost for most general-purpose workloads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GceHyperdiskBalancedHighAvailability

Returns a new instance of GceHyperdiskBalancedHighAvailability.



594
595
596
# File 'lib/google/apis/workstations_v1/classes.rb', line 594

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#archive_timeoutString

Optional. Number of seconds to wait after initially creating or subsequently shutting down the workstation before converting its disk into a snapshot. This generally saves costs at the expense of greater startup time on next workstation start, as the service will need to create a disk from the archival snapshot. A value of "0s" indicates that the disk will never be archived. Corresponds to the JSON property archiveTimeout

Returns:

  • (String)


564
565
566
# File 'lib/google/apis/workstations_v1/classes.rb', line 564

def archive_timeout
  @archive_timeout
end

#max_size_gbFixnum

Optional. Maximum size in GB to which this persistent directory can be resized. Defaults to 0, which indicates no maximum limit is enforced by this configuration. Resizing is still subject to the quotas and limits of the underlying disk type. Corresponds to the JSON property maxSizeGb

Returns:

  • (Fixnum)


572
573
574
# File 'lib/google/apis/workstations_v1/classes.rb', line 572

def max_size_gb
  @max_size_gb
end

#reclaim_policyString

Optional. Whether the persistent disk should be deleted when the workstation is deleted. Valid values are DELETE and RETAIN. Defaults to DELETE. Corresponds to the JSON property reclaimPolicy

Returns:

  • (String)


578
579
580
# File 'lib/google/apis/workstations_v1/classes.rb', line 578

def reclaim_policy
  @reclaim_policy
end

#size_gbFixnum

Optional. The GB capacity of a persistent home directory for each workstation created with this configuration. Must be empty if source_snapshot is set. Valid values are 10, 50, 100, 200, 500, or 1000. Defaults to 200. Corresponds to the JSON property sizeGb

Returns:

  • (Fixnum)


585
586
587
# File 'lib/google/apis/workstations_v1/classes.rb', line 585

def size_gb
  @size_gb
end

#source_snapshotString

Optional. Name of the snapshot to use as the source for the disk. If set, size_gb must be empty. Must be formatted as ext4 file system with no partitions. Corresponds to the JSON property sourceSnapshot

Returns:

  • (String)


592
593
594
# File 'lib/google/apis/workstations_v1/classes.rb', line 592

def source_snapshot
  @source_snapshot
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



599
600
601
602
603
604
605
# File 'lib/google/apis/workstations_v1/classes.rb', line 599

def update!(**args)
  @archive_timeout = args[:archive_timeout] if args.key?(:archive_timeout)
  @max_size_gb = args[:max_size_gb] if args.key?(:max_size_gb)
  @reclaim_policy = args[:reclaim_policy] if args.key?(:reclaim_policy)
  @size_gb = args[:size_gb] if args.key?(:size_gb)
  @source_snapshot = args[:source_snapshot] if args.key?(:source_snapshot)
end