Class: Google::Apis::WorkstationsV1::ListWorkstationClustersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1/classes.rb,
lib/google/apis/workstations_v1/representations.rb,
lib/google/apis/workstations_v1/representations.rb

Overview

Response message for ListWorkstationClusters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListWorkstationClustersResponse

Returns a new instance of ListWorkstationClustersResponse.



1221
1222
1223
# File 'lib/google/apis/workstations_v1/classes.rb', line 1221

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1209
1210
1211
# File 'lib/google/apis/workstations_v1/classes.rb', line 1209

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unreachable resources. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1214
1215
1216
# File 'lib/google/apis/workstations_v1/classes.rb', line 1214

def unreachable
  @unreachable
end

#workstation_clustersArray<Google::Apis::WorkstationsV1::WorkstationCluster>

The requested workstation clusters. Corresponds to the JSON property workstationClusters



1219
1220
1221
# File 'lib/google/apis/workstations_v1/classes.rb', line 1219

def workstation_clusters
  @workstation_clusters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1226
1227
1228
1229
1230
# File 'lib/google/apis/workstations_v1/classes.rb', line 1226

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
  @workstation_clusters = args[:workstation_clusters] if args.key?(:workstation_clusters)
end