Class: Google::Apis::WorkstationsV1::ListWorkstationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1/classes.rb,
lib/google/apis/workstations_v1/representations.rb,
lib/google/apis/workstations_v1/representations.rb

Overview

Response message for ListWorkstations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListWorkstationsResponse

Returns a new instance of ListWorkstationsResponse.



1289
1290
1291
# File 'lib/google/apis/workstations_v1/classes.rb', line 1289

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Optional. Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1277
1278
1279
# File 'lib/google/apis/workstations_v1/classes.rb', line 1277

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Optional. Unreachable resources. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1282
1283
1284
# File 'lib/google/apis/workstations_v1/classes.rb', line 1282

def unreachable
  @unreachable
end

#workstationsArray<Google::Apis::WorkstationsV1::Workstation>

The requested workstations. Corresponds to the JSON property workstations



1287
1288
1289
# File 'lib/google/apis/workstations_v1/classes.rb', line 1287

def workstations
  @workstations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1294
1295
1296
1297
1298
# File 'lib/google/apis/workstations_v1/classes.rb', line 1294

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
  @workstations = args[:workstations] if args.key?(:workstations)
end