Class: Google::Apis::WorkstationsV1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1/classes.rb,
lib/google/apis/workstations_v1/representations.rb,
lib/google/apis/workstations_v1/representations.rb

Overview

Metadata for long-running operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



1451
1452
1453
# File 'lib/google/apis/workstations_v1/classes.rb', line 1451

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


1417
1418
1419
# File 'lib/google/apis/workstations_v1/classes.rb', line 1417

def api_version
  @api_version
end

#create_timeString

Output only. Time that the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1422
1423
1424
# File 'lib/google/apis/workstations_v1/classes.rb', line 1422

def create_time
  @create_time
end

#end_timeString

Output only. Time that the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


1427
1428
1429
# File 'lib/google/apis/workstations_v1/classes.rb', line 1427

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


1433
1434
1435
# File 'lib/google/apis/workstations_v1/classes.rb', line 1433

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


1439
1440
1441
# File 'lib/google/apis/workstations_v1/classes.rb', line 1439

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


1444
1445
1446
# File 'lib/google/apis/workstations_v1/classes.rb', line 1444

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


1449
1450
1451
# File 'lib/google/apis/workstations_v1/classes.rb', line 1449

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1456
1457
1458
1459
1460
1461
1462
1463
1464
# File 'lib/google/apis/workstations_v1/classes.rb', line 1456

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end