Class: Google::Apis::WorkstationsV1::StopWorkstationRequest
- Inherits:
-
Object
- Object
- Google::Apis::WorkstationsV1::StopWorkstationRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workstations_v1/classes.rb,
lib/google/apis/workstations_v1/representations.rb,
lib/google/apis/workstations_v1/representations.rb
Overview
Request message for StopWorkstation.
Instance Attribute Summary collapse
-
#etag ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StopWorkstationRequest
constructor
A new instance of StopWorkstationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StopWorkstationRequest
Returns a new instance of StopWorkstationRequest.
1868 1869 1870 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 1868 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Optional. If set, the request will be rejected if the latest version of the
workstation on the server does not have this ETag.
Corresponds to the JSON property etag
1859 1860 1861 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 1859 def etag @etag end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. If set, validate the request and preview the result, but do not
actually apply it.
Corresponds to the JSON property validateOnly
1865 1866 1867 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 1865 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1873 1874 1875 1876 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 1873 def update!(**args) @etag = args[:etag] if args.key?(:etag) @validate_only = args[:validate_only] if args.key?(:validate_only) end |