Class: Google::Apis::WorkstationsV1::WorkstationPersistentDirectory
- Inherits:
-
Object
- Object
- Google::Apis::WorkstationsV1::WorkstationPersistentDirectory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workstations_v1/classes.rb,
lib/google/apis/workstations_v1/representations.rb,
lib/google/apis/workstations_v1/representations.rb
Overview
A directory to persist across workstation sessions. Updates to this field will only take effect on this workstation after it is restarted.
Instance Attribute Summary collapse
-
#mount_path ⇒ String
Optional.
-
#size_gb ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkstationPersistentDirectory
constructor
A new instance of WorkstationPersistentDirectory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkstationPersistentDirectory
Returns a new instance of WorkstationPersistentDirectory.
2483 2484 2485 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2483 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mount_path ⇒ String
Optional. The mount path of the persistent directory.
Corresponds to the JSON property mountPath
2475 2476 2477 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2475 def mount_path @mount_path end |
#size_gb ⇒ Fixnum
Optional. Size of the persistent directory in GB. If specified in an update
request, this is the desired size of the directory.
Corresponds to the JSON property sizeGb
2481 2482 2483 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2481 def size_gb @size_gb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2488 2489 2490 2491 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2488 def update!(**args) @mount_path = args[:mount_path] if args.key?(:mount_path) @size_gb = args[:size_gb] if args.key?(:size_gb) end |