Class: Google::Apis::WorkstationsV1::GceHyperdiskBalancedHighAvailability
- Inherits:
-
Object
- Object
- Google::Apis::WorkstationsV1::GceHyperdiskBalancedHighAvailability
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workstations_v1/classes.rb,
lib/google/apis/workstations_v1/representations.rb,
lib/google/apis/workstations_v1/representations.rb
Overview
A Persistent Directory backed by a Compute Engine Hyperdisk Balanced High Availability Disk. This is a high-availability block storage solution that offers a balance between performance and cost for most general-purpose workloads.
Instance Attribute Summary collapse
-
#archive_timeout ⇒ String
Optional.
-
#max_size_gb ⇒ Fixnum
Optional.
-
#reclaim_policy ⇒ String
Optional.
-
#size_gb ⇒ Fixnum
Optional.
-
#source_snapshot ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GceHyperdiskBalancedHighAvailability
constructor
A new instance of GceHyperdiskBalancedHighAvailability.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GceHyperdiskBalancedHighAvailability
Returns a new instance of GceHyperdiskBalancedHighAvailability.
592 593 594 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 592 def initialize(**args) update!(**args) end |
Instance Attribute Details
#archive_timeout ⇒ String
Optional. Number of seconds to wait after initially creating or subsequently
shutting down the workstation before converting its disk into a snapshot. This
generally saves costs at the expense of greater startup time on next
workstation start, as the service will need to create a disk from the archival
snapshot. A value of "0s" indicates that the disk will never be archived.
Corresponds to the JSON property archiveTimeout
564 565 566 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 564 def archive_timeout @archive_timeout end |
#max_size_gb ⇒ Fixnum
Optional. Maximum size in GB to which this persistent directory can be resized.
Defaults to unlimited if not set.
Corresponds to the JSON property maxSizeGb
570 571 572 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 570 def max_size_gb @max_size_gb end |
#reclaim_policy ⇒ String
Optional. Whether the persistent disk should be deleted when the workstation
is deleted. Valid values are DELETE and RETAIN. Defaults to DELETE.
Corresponds to the JSON property reclaimPolicy
576 577 578 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 576 def reclaim_policy @reclaim_policy end |
#size_gb ⇒ Fixnum
Optional. The GB capacity of a persistent home directory for each workstation
created with this configuration. Must be empty if source_snapshot is set.
Valid values are 10, 50, 100, 200, 500, or 1000. Defaults to 200.
Corresponds to the JSON property sizeGb
583 584 585 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 583 def size_gb @size_gb end |
#source_snapshot ⇒ String
Optional. Name of the snapshot to use as the source for the disk. If set,
size_gb must be empty. Must be formatted as ext4 file system with no
partitions.
Corresponds to the JSON property sourceSnapshot
590 591 592 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 590 def source_snapshot @source_snapshot end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
597 598 599 600 601 602 603 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 597 def update!(**args) @archive_timeout = args[:archive_timeout] if args.key?(:archive_timeout) @max_size_gb = args[:max_size_gb] if args.key?(:max_size_gb) @reclaim_policy = args[:reclaim_policy] if args.key?(:reclaim_policy) @size_gb = args[:size_gb] if args.key?(:size_gb) @source_snapshot = args[:source_snapshot] if args.key?(:source_snapshot) end |