Class: Google::Apis::WorkstationsV1::GceInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1/classes.rb,
lib/google/apis/workstations_v1/representations.rb,
lib/google/apis/workstations_v1/representations.rb

Overview

A runtime using a Compute Engine instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GceInstance

Returns a new instance of GceInstance.



752
753
754
# File 'lib/google/apis/workstations_v1/classes.rb', line 752

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acceleratorsArray<Google::Apis::WorkstationsV1::Accelerator>

Optional. A list of the type and count of accelerator cards attached to the instance. Corresponds to the JSON property accelerators



607
608
609
# File 'lib/google/apis/workstations_v1/classes.rb', line 607

def accelerators
  @accelerators
end

#boost_configsArray<Google::Apis::WorkstationsV1::BoostConfig>

Optional. A list of the boost configurations that workstations created using this workstation configuration are allowed to use. If specified, users will have the option to choose from the list of boost configs when starting a workstation. Corresponds to the JSON property boostConfigs



615
616
617
# File 'lib/google/apis/workstations_v1/classes.rb', line 615

def boost_configs
  @boost_configs
end

#boot_disk_size_gbFixnum

Optional. The size of the boot disk for the VM in gigabytes (GB). The minimum boot disk size is 30 GB. Defaults to 50 GB. Corresponds to the JSON property bootDiskSizeGb

Returns:

  • (Fixnum)


621
622
623
# File 'lib/google/apis/workstations_v1/classes.rb', line 621

def boot_disk_size_gb
  @boot_disk_size_gb
end

#confidential_instance_configGoogle::Apis::WorkstationsV1::GceConfidentialInstanceConfig

A set of Compute Engine Confidential VM instance options. Corresponds to the JSON property confidentialInstanceConfig



626
627
628
# File 'lib/google/apis/workstations_v1/classes.rb', line 626

def confidential_instance_config
  @confidential_instance_config
end

#disable_public_ip_addressesBoolean Also known as: disable_public_ip_addresses?

Optional. When set to true, disables public IP addresses for VMs. If you disable public IP addresses, you must set up Private Google Access or Cloud NAT on your network. If you use Private Google Access and you use private. googleapis.com or restricted.googleapis.com for Container Registry and Artifact Registry, make sure that you set up DNS records for domains *.gcr.io and *.pkg.dev. Defaults to false (VMs have public IP addresses). Corresponds to the JSON property disablePublicIpAddresses

Returns:

  • (Boolean)


636
637
638
# File 'lib/google/apis/workstations_v1/classes.rb', line 636

def disable_public_ip_addresses
  @disable_public_ip_addresses
end

#disable_sshBoolean Also known as: disable_ssh?

Optional. Whether to disable SSH access to the VM. Corresponds to the JSON property disableSsh

Returns:

  • (Boolean)


642
643
644
# File 'lib/google/apis/workstations_v1/classes.rb', line 642

def disable_ssh
  @disable_ssh
end

#enable_nested_virtualizationBoolean Also known as: enable_nested_virtualization?

Optional. Whether to enable nested virtualization on Cloud Workstations VMs created using this workstation configuration. Defaults to false. Nested virtualization lets you run virtual machine (VM) instances inside your workstation. Before enabling nested virtualization, consider the following important considerations. Cloud Workstations instances are subject to the same restrictions as Compute Engine instances: * ** Organization policy*: projects, folders, or organizations may be restricted from creating nested VMs if the **Disable VM nested virtualization* constraint is enforced in the organization policy. For more information, see the Compute Engine section, Checking whether nested virtualization is allowed. * ** Performance*: nested VMs might experience a 10% or greater decrease in performance for workloads that are CPU-bound and possibly greater than a 10% decrease for workloads that are input/output bound. * **Machine Type*: nested virtualization can only be enabled on workstation configurations that specify a machine_type in the N1 or N2 machine series. Corresponds to the JSON property enableNestedVirtualization

Returns:

  • (Boolean)


665
666
667
# File 'lib/google/apis/workstations_v1/classes.rb', line 665

def enable_nested_virtualization
  @enable_nested_virtualization
end

#instance_metadataHash<String,String>

Optional. Custom metadata to apply to Compute Engine instances. Corresponds to the JSON property instanceMetadata

Returns:

  • (Hash<String,String>)


671
672
673
# File 'lib/google/apis/workstations_v1/classes.rb', line 671

def 
  @instance_metadata
end

#machine_typeString

Optional. The type of machine to use for VM instances—for example, "e2- standard-4". For more information about machine types that Cloud Workstations supports, see the list of available machine types. Corresponds to the JSON property machineType

Returns:

  • (String)


679
680
681
# File 'lib/google/apis/workstations_v1/classes.rb', line 679

def machine_type
  @machine_type
end

#pool_sizeFixnum

Optional. The number of VMs that the system should keep idle so that new workstations can be started quickly for new users. Defaults to 0 in the API. Corresponds to the JSON property poolSize

Returns:

  • (Fixnum)


685
686
687
# File 'lib/google/apis/workstations_v1/classes.rb', line 685

def pool_size
  @pool_size
end

#pooled_instancesFixnum

Output only. Number of instances currently available in the pool for faster workstation startup. Corresponds to the JSON property pooledInstances

Returns:

  • (Fixnum)


691
692
693
# File 'lib/google/apis/workstations_v1/classes.rb', line 691

def pooled_instances
  @pooled_instances
end

#service_accountString

Optional. The email address of the service account for Cloud Workstations VMs created with this configuration. When specified, be sure that the service account has logging.logEntries.create and monitoring.timeSeries.create permissions on the project so it can write logs out to Cloud Logging. If using a custom container image, the service account must have Artifact Registry Reader permission to pull the specified image. If you as the administrator want to be able to ssh into the underlying VM, you need to set this value to a service account for which you have the iam.serviceAccounts.actAs permission. Conversely, if you don't want anyone to be able to ssh into the underlying VM, use a service account where no one has that permission. If not set, VMs run with a service account provided by the Cloud Workstations service, and the image must be publicly accessible. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


708
709
710
# File 'lib/google/apis/workstations_v1/classes.rb', line 708

def 
  @service_account
end

#service_account_scopesArray<String>

Optional. Scopes to grant to the service_account. When specified, users of workstations under this configuration must have iam.serviceAccounts.actAs on the service account. Corresponds to the JSON property serviceAccountScopes

Returns:

  • (Array<String>)


715
716
717
# File 'lib/google/apis/workstations_v1/classes.rb', line 715

def 
  @service_account_scopes
end

#shielded_instance_configGoogle::Apis::WorkstationsV1::GceShieldedInstanceConfig

A set of Compute Engine Shielded instance options. Corresponds to the JSON property shieldedInstanceConfig



720
721
722
# File 'lib/google/apis/workstations_v1/classes.rb', line 720

def shielded_instance_config
  @shielded_instance_config
end

#startup_script_uriString

Optional. Link to the startup script stored in Cloud Storage. This script will be run on the host workstation VM when the VM is created. The URI must be of the form gs://bucket-name/object-name. If specifying a startup script, the service account must have Permission to access the bucket and script file in Cloud Storage. Otherwise, the script must be publicly accessible. Note that the service regularly updates the OS version of the host VM, and it is the responsibility of the user to ensure the script stays compatible with the OS version. Corresponds to the JSON property startupScriptUri

Returns:

  • (String)


733
734
735
# File 'lib/google/apis/workstations_v1/classes.rb', line 733

def startup_script_uri
  @startup_script_uri
end

#tagsArray<String>

Optional. Network tags to add to the Compute Engine VMs backing the workstations. This option applies network tags to VMs created with this configuration. These network tags enable the creation of firewall rules. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


742
743
744
# File 'lib/google/apis/workstations_v1/classes.rb', line 742

def tags
  @tags
end

#vm_tagsHash<String,String>

Optional. Resource manager tags to be bound to this instance. Tag keys and values have the same definition as resource manager tags. Keys must be in the format tagKeys/tag_key_id`, and values are in the formattagValues/456. Corresponds to the JSON propertyvmTags`

Returns:

  • (Hash<String,String>)


750
751
752
# File 'lib/google/apis/workstations_v1/classes.rb', line 750

def vm_tags
  @vm_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
# File 'lib/google/apis/workstations_v1/classes.rb', line 757

def update!(**args)
  @accelerators = args[:accelerators] if args.key?(:accelerators)
  @boost_configs = args[:boost_configs] if args.key?(:boost_configs)
  @boot_disk_size_gb = args[:boot_disk_size_gb] if args.key?(:boot_disk_size_gb)
  @confidential_instance_config = args[:confidential_instance_config] if args.key?(:confidential_instance_config)
  @disable_public_ip_addresses = args[:disable_public_ip_addresses] if args.key?(:disable_public_ip_addresses)
  @disable_ssh = args[:disable_ssh] if args.key?(:disable_ssh)
  @enable_nested_virtualization = args[:enable_nested_virtualization] if args.key?(:enable_nested_virtualization)
  @instance_metadata = args[:instance_metadata] if args.key?(:instance_metadata)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @pool_size = args[:pool_size] if args.key?(:pool_size)
  @pooled_instances = args[:pooled_instances] if args.key?(:pooled_instances)
  @service_account = args[:service_account] if args.key?(:service_account)
  @service_account_scopes = args[:service_account_scopes] if args.key?(:service_account_scopes)
  @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config)
  @startup_script_uri = args[:startup_script_uri] if args.key?(:startup_script_uri)
  @tags = args[:tags] if args.key?(:tags)
  @vm_tags = args[:vm_tags] if args.key?(:vm_tags)
end