Class: Google::Apis::WorkstationsV1::GenerateAccessTokenRequest
- Inherits:
-
Object
- Object
- Google::Apis::WorkstationsV1::GenerateAccessTokenRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workstations_v1/classes.rb,
lib/google/apis/workstations_v1/representations.rb,
lib/google/apis/workstations_v1/representations.rb
Overview
Request message for GenerateAccessToken.
Instance Attribute Summary collapse
-
#expire_time ⇒ String
Desired expiration time of the access token.
-
#port ⇒ Fixnum
Optional.
-
#ttl ⇒ String
Desired lifetime duration of the access token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenerateAccessTokenRequest
constructor
A new instance of GenerateAccessTokenRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenerateAccessTokenRequest
Returns a new instance of GenerateAccessTokenRequest.
980 981 982 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 980 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expire_time ⇒ String
Desired expiration time of the access token. This value must be at most 24
hours in the future. If a value is not specified, the token's expiration time
will be set to a default value of 1 hour in the future.
Corresponds to the JSON property expireTime
962 963 964 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 962 def expire_time @expire_time end |
#port ⇒ Fixnum
Optional. Port for which the access token should be generated. If specified,
the generated access token grants access only to the specified port of the
workstation. If specified, values must be within the range [1 - 65535]. If not
specified, the generated access token grants access to all ports of the
workstation.
Corresponds to the JSON property port
971 972 973 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 971 def port @port end |
#ttl ⇒ String
Desired lifetime duration of the access token. This value must be at most 24
hours. If a value is not specified, the token's lifetime will be set to a
default value of 1 hour.
Corresponds to the JSON property ttl
978 979 980 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 978 def ttl @ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
985 986 987 988 989 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 985 def update!(**args) @expire_time = args[:expire_time] if args.key?(:expire_time) @port = args[:port] if args.key?(:port) @ttl = args[:ttl] if args.key?(:ttl) end |