Class: Google::Apis::WorkstationsV1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1/classes.rb,
lib/google/apis/workstations_v1/representations.rb,
lib/google/apis/workstations_v1/representations.rb

Overview

Metadata for long-running operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



1423
1424
1425
# File 'lib/google/apis/workstations_v1/classes.rb', line 1423

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


1389
1390
1391
# File 'lib/google/apis/workstations_v1/classes.rb', line 1389

def api_version
  @api_version
end

#create_timeString

Output only. Time that the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1394
1395
1396
# File 'lib/google/apis/workstations_v1/classes.rb', line 1394

def create_time
  @create_time
end

#end_timeString

Output only. Time that the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


1399
1400
1401
# File 'lib/google/apis/workstations_v1/classes.rb', line 1399

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


1405
1406
1407
# File 'lib/google/apis/workstations_v1/classes.rb', line 1405

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


1411
1412
1413
# File 'lib/google/apis/workstations_v1/classes.rb', line 1411

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


1416
1417
1418
# File 'lib/google/apis/workstations_v1/classes.rb', line 1416

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


1421
1422
1423
# File 'lib/google/apis/workstations_v1/classes.rb', line 1421

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1428
1429
1430
1431
1432
1433
1434
1435
1436
# File 'lib/google/apis/workstations_v1/classes.rb', line 1428

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end