Class: Google::Apis::WorkstationsV1::PersistentDirectory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1/classes.rb,
lib/google/apis/workstations_v1/representations.rb,
lib/google/apis/workstations_v1/representations.rb

Overview

A directory to persist across workstation sessions. Updates to this field will not update existing workstations and will only take effect on new workstations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PersistentDirectory

Returns a new instance of PersistentDirectory.



1479
1480
1481
# File 'lib/google/apis/workstations_v1/classes.rb', line 1479

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gce_hdGoogle::Apis::WorkstationsV1::GceHyperdiskBalancedHighAvailability

A Persistent Directory backed by a Compute Engine Hyperdisk Balanced High Availability Disk. This is a high-availability block storage solution that offers a balance between performance and cost for most general-purpose workloads. Corresponds to the JSON property gceHd



1461
1462
1463
# File 'lib/google/apis/workstations_v1/classes.rb', line 1461

def gce_hd
  @gce_hd
end

#gce_pdGoogle::Apis::WorkstationsV1::GceRegionalPersistentDisk

A Persistent Directory backed by a Compute Engine regional persistent disk. The persistent_directories field is repeated, but it may contain only one entry. It creates a persistent disk that mounts to the workstation VM at /home when the session starts and detaches when the session ends. If this field is empty, workstations created with this configuration do not have a persistent home directory. Corresponds to the JSON property gcePd



1472
1473
1474
# File 'lib/google/apis/workstations_v1/classes.rb', line 1472

def gce_pd
  @gce_pd
end

#mount_pathString

Optional. Location of this directory in the running workstation. Corresponds to the JSON property mountPath

Returns:

  • (String)


1477
1478
1479
# File 'lib/google/apis/workstations_v1/classes.rb', line 1477

def mount_path
  @mount_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1484
1485
1486
1487
1488
# File 'lib/google/apis/workstations_v1/classes.rb', line 1484

def update!(**args)
  @gce_hd = args[:gce_hd] if args.key?(:gce_hd)
  @gce_pd = args[:gce_pd] if args.key?(:gce_pd)
  @mount_path = args[:mount_path] if args.key?(:mount_path)
end