Class: Google::Apis::WorkstationsV1::PrivateClusterConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1/classes.rb,
lib/google/apis/workstations_v1/representations.rb,
lib/google/apis/workstations_v1/representations.rb

Overview

Configuration options for private workstation clusters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrivateClusterConfig

Returns a new instance of PrivateClusterConfig.



1639
1640
1641
# File 'lib/google/apis/workstations_v1/classes.rb', line 1639

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_projectsArray<String>

Optional. Additional projects that are allowed to attach to the workstation cluster's service attachment. By default, the workstation cluster's project and the VPC host project (if different) are allowed. Corresponds to the JSON property allowedProjects

Returns:

  • (Array<String>)


1613
1614
1615
# File 'lib/google/apis/workstations_v1/classes.rb', line 1613

def allowed_projects
  @allowed_projects
end

#cluster_hostnameString

Output only. Hostname for the workstation cluster. This field will be populated only when private endpoint is enabled. To access workstations in the workstation cluster, create a new DNS zone mapping this domain name to an internal IP address and a forwarding rule mapping that address to the service attachment. Corresponds to the JSON property clusterHostname

Returns:

  • (String)


1622
1623
1624
# File 'lib/google/apis/workstations_v1/classes.rb', line 1622

def cluster_hostname
  @cluster_hostname
end

#enable_private_endpointBoolean Also known as: enable_private_endpoint?

Immutable. Whether Workstations endpoint is private. Corresponds to the JSON property enablePrivateEndpoint

Returns:

  • (Boolean)


1627
1628
1629
# File 'lib/google/apis/workstations_v1/classes.rb', line 1627

def enable_private_endpoint
  @enable_private_endpoint
end

#service_attachment_uriString

Output only. Service attachment URI for the workstation cluster. The service attachment is created when private endpoint is enabled. To access workstations in the workstation cluster, configure access to the managed service using Private Service Connect. Corresponds to the JSON property serviceAttachmentUri

Returns:

  • (String)


1637
1638
1639
# File 'lib/google/apis/workstations_v1/classes.rb', line 1637

def service_attachment_uri
  @service_attachment_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1644
1645
1646
1647
1648
1649
# File 'lib/google/apis/workstations_v1/classes.rb', line 1644

def update!(**args)
  @allowed_projects = args[:allowed_projects] if args.key?(:allowed_projects)
  @cluster_hostname = args[:cluster_hostname] if args.key?(:cluster_hostname)
  @enable_private_endpoint = args[:enable_private_endpoint] if args.key?(:enable_private_endpoint)
  @service_attachment_uri = args[:service_attachment_uri] if args.key?(:service_attachment_uri)
end