Class: Google::Apis::WorkstationsV1::StartWorkstationRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1/classes.rb,
lib/google/apis/workstations_v1/representations.rb,
lib/google/apis/workstations_v1/representations.rb

Overview

Request message for StartWorkstation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StartWorkstationRequest

Returns a new instance of StartWorkstationRequest.



1772
1773
1774
# File 'lib/google/apis/workstations_v1/classes.rb', line 1772

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boost_configString

Optional. If set, the workstation starts using the boost configuration with the specified ID. Corresponds to the JSON property boostConfig

Returns:

  • (String)


1757
1758
1759
# File 'lib/google/apis/workstations_v1/classes.rb', line 1757

def boost_config
  @boost_config
end

#etagString

Optional. If set, the request will be rejected if the latest version of the workstation on the server does not have this ETag. Corresponds to the JSON property etag

Returns:

  • (String)


1763
1764
1765
# File 'lib/google/apis/workstations_v1/classes.rb', line 1763

def etag
  @etag
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set, validate the request and preview the result, but do not actually apply it. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


1769
1770
1771
# File 'lib/google/apis/workstations_v1/classes.rb', line 1769

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1777
1778
1779
1780
1781
# File 'lib/google/apis/workstations_v1/classes.rb', line 1777

def update!(**args)
  @boost_config = args[:boost_config] if args.key?(:boost_config)
  @etag = args[:etag] if args.key?(:etag)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end