Class: Google::Apis::WorkstationsV1::StopWorkstationRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1/classes.rb,
lib/google/apis/workstations_v1/representations.rb,
lib/google/apis/workstations_v1/representations.rb

Overview

Request message for StopWorkstation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StopWorkstationRequest

Returns a new instance of StopWorkstationRequest.



1850
1851
1852
# File 'lib/google/apis/workstations_v1/classes.rb', line 1850

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Optional. If set, the request will be rejected if the latest version of the workstation on the server does not have this ETag. Corresponds to the JSON property etag

Returns:

  • (String)


1841
1842
1843
# File 'lib/google/apis/workstations_v1/classes.rb', line 1841

def etag
  @etag
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set, validate the request and preview the result, but do not actually apply it. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


1847
1848
1849
# File 'lib/google/apis/workstations_v1/classes.rb', line 1847

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1855
1856
1857
1858
# File 'lib/google/apis/workstations_v1/classes.rb', line 1855

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end