Class: Google::Apis::WorkstationsV1::StopWorkstationRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1/classes.rb,
lib/google/apis/workstations_v1/representations.rb,
lib/google/apis/workstations_v1/representations.rb

Overview

Request message for StopWorkstation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StopWorkstationRequest

Returns a new instance of StopWorkstationRequest.



1840
1841
1842
# File 'lib/google/apis/workstations_v1/classes.rb', line 1840

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Optional. If set, the request will be rejected if the latest version of the workstation on the server does not have this ETag. Corresponds to the JSON property etag

Returns:

  • (String)


1831
1832
1833
# File 'lib/google/apis/workstations_v1/classes.rb', line 1831

def etag
  @etag
end

#validate_onlyBoolean Also known as: validate_only?

Optional. If set, validate the request and preview the result, but do not actually apply it. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


1837
1838
1839
# File 'lib/google/apis/workstations_v1/classes.rb', line 1837

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1845
1846
1847
1848
# File 'lib/google/apis/workstations_v1/classes.rb', line 1845

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end