Class: Google::Apis::WorkstationsV1::Workstation
- Inherits:
-
Object
- Object
- Google::Apis::WorkstationsV1::Workstation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workstations_v1/classes.rb,
lib/google/apis/workstations_v1/representations.rb,
lib/google/apis/workstations_v1/representations.rb
Overview
A single instance of a developer workstation with its own persistent storage.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#env ⇒ Hash<String,String>
Optional.
-
#etag ⇒ String
Optional.
-
#host ⇒ String
Output only.
-
#kms_key ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#persistent_directories ⇒ Array<Google::Apis::WorkstationsV1::WorkstationPersistentDirectory>
Optional.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#runtime_host ⇒ Google::Apis::WorkstationsV1::RuntimeHost
Runtime host for the workstation.
-
#source_workstation ⇒ String
Optional.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Workstation
constructor
A new instance of Workstation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Workstation
Returns a new instance of Workstation.
2027 2028 2029 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2027 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Client-specified annotations.
Corresponds to the JSON property annotations
1926 1927 1928 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 1926 def annotations @annotations end |
#create_time ⇒ String
Output only. Time when this workstation was created.
Corresponds to the JSON property createTime
1931 1932 1933 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 1931 def create_time @create_time end |
#delete_time ⇒ String
Output only. Time when this workstation was soft-deleted.
Corresponds to the JSON property deleteTime
1936 1937 1938 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 1936 def delete_time @delete_time end |
#display_name ⇒ String
Optional. Human-readable name for this workstation.
Corresponds to the JSON property displayName
1941 1942 1943 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 1941 def display_name @display_name end |
#env ⇒ Hash<String,String>
Optional. Environment variables passed to the workstation container's
entrypoint.
Corresponds to the JSON property env
1947 1948 1949 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 1947 def env @env end |
#etag ⇒ String
Optional. Checksum computed by the server. May be sent on update and delete
requests to make sure that the client has an up-to-date value before
proceeding.
Corresponds to the JSON property etag
1954 1955 1956 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 1954 def etag @etag end |
#host ⇒ String
Output only. Host to which clients can send HTTPS traffic that will be
received by the workstation. Authorized traffic will be received to the
workstation as HTTP on port 80. To send traffic to a different port, clients
may prefix the host with the destination port in the format port`-`host.
Corresponds to the JSON property host
1962 1963 1964 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 1962 def host @host end |
#kms_key ⇒ String
Output only. The name of the Google Cloud KMS encryption key used to encrypt
this workstation. The KMS key can only be configured in the WorkstationConfig.
The expected format is projects/*/locations/*/keyRings/*/cryptoKeys/*.
Corresponds to the JSON property kmsKey
1969 1970 1971 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 1969 def kms_key @kms_key end |
#labels ⇒ Hash<String,String>
Optional. Labels
that are applied to the workstation and that are also propagated to the
underlying Compute Engine resources.
Corresponds to the JSON property labels
1976 1977 1978 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 1976 def labels @labels end |
#name ⇒ String
Identifier. Full name of this workstation.
Corresponds to the JSON property name
1981 1982 1983 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 1981 def name @name end |
#persistent_directories ⇒ Array<Google::Apis::WorkstationsV1::WorkstationPersistentDirectory>
Optional. Directories to persist across workstation sessions.
Corresponds to the JSON property persistentDirectories
1986 1987 1988 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 1986 def persistent_directories @persistent_directories end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Indicates whether this workstation is currently being updated to
match its intended state.
Corresponds to the JSON property reconciling
1992 1993 1994 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 1992 def reconciling @reconciling end |
#runtime_host ⇒ Google::Apis::WorkstationsV1::RuntimeHost
Runtime host for the workstation.
Corresponds to the JSON property runtimeHost
1998 1999 2000 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 1998 def runtime_host @runtime_host end |
#source_workstation ⇒ String
Optional. The source workstation from which this workstation's persistent
directories were cloned on creation.
Corresponds to the JSON property sourceWorkstation
2004 2005 2006 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2004 def source_workstation @source_workstation end |
#start_time ⇒ String
Output only. Time when this workstation was most recently successfully started,
regardless of the workstation's initial state.
Corresponds to the JSON property startTime
2010 2011 2012 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2010 def start_time @start_time end |
#state ⇒ String
Output only. Current state of the workstation.
Corresponds to the JSON property state
2015 2016 2017 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2015 def state @state end |
#uid ⇒ String
Output only. A system-assigned unique identifier for this workstation.
Corresponds to the JSON property uid
2020 2021 2022 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2020 def uid @uid end |
#update_time ⇒ String
Output only. Time when this workstation was most recently updated.
Corresponds to the JSON property updateTime
2025 2026 2027 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2025 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2032 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @env = args[:env] if args.key?(:env) @etag = args[:etag] if args.key?(:etag) @host = args[:host] if args.key?(:host) @kms_key = args[:kms_key] if args.key?(:kms_key) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @persistent_directories = args[:persistent_directories] if args.key?(:persistent_directories) @reconciling = args[:reconciling] if args.key?(:reconciling) @runtime_host = args[:runtime_host] if args.key?(:runtime_host) @source_workstation = args[:source_workstation] if args.key?(:source_workstation) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |