Class: Google::Apis::WorkstationsV1::Workstation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1/classes.rb,
lib/google/apis/workstations_v1/representations.rb,
lib/google/apis/workstations_v1/representations.rb

Overview

A single instance of a developer workstation with its own persistent storage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Workstation

Returns a new instance of Workstation.



2023
2024
2025
# File 'lib/google/apis/workstations_v1/classes.rb', line 2023

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Client-specified annotations. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


1922
1923
1924
# File 'lib/google/apis/workstations_v1/classes.rb', line 1922

def annotations
  @annotations
end

#create_timeString

Output only. Time when this workstation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1927
1928
1929
# File 'lib/google/apis/workstations_v1/classes.rb', line 1927

def create_time
  @create_time
end

#delete_timeString

Output only. Time when this workstation was soft-deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


1932
1933
1934
# File 'lib/google/apis/workstations_v1/classes.rb', line 1932

def delete_time
  @delete_time
end

#display_nameString

Optional. Human-readable name for this workstation. Corresponds to the JSON property displayName

Returns:

  • (String)


1937
1938
1939
# File 'lib/google/apis/workstations_v1/classes.rb', line 1937

def display_name
  @display_name
end

#envHash<String,String>

Optional. Environment variables passed to the workstation container's entrypoint. Corresponds to the JSON property env

Returns:

  • (Hash<String,String>)


1943
1944
1945
# File 'lib/google/apis/workstations_v1/classes.rb', line 1943

def env
  @env
end

#etagString

Optional. Checksum computed by the server. May be sent on update and delete requests to make sure that the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


1950
1951
1952
# File 'lib/google/apis/workstations_v1/classes.rb', line 1950

def etag
  @etag
end

#hostString

Output only. Host to which clients can send HTTPS traffic that will be received by the workstation. Authorized traffic will be received to the workstation as HTTP on port 80. To send traffic to a different port, clients may prefix the host with the destination port in the format port`-`host. Corresponds to the JSON property host

Returns:

  • (String)


1958
1959
1960
# File 'lib/google/apis/workstations_v1/classes.rb', line 1958

def host
  @host
end

#kms_keyString

Output only. The name of the Google Cloud KMS encryption key used to encrypt this workstation. The KMS key can only be configured in the WorkstationConfig. The expected format is projects/*/locations/*/keyRings/*/cryptoKeys/*. Corresponds to the JSON property kmsKey

Returns:

  • (String)


1965
1966
1967
# File 'lib/google/apis/workstations_v1/classes.rb', line 1965

def kms_key
  @kms_key
end

#labelsHash<String,String>

Optional. Labels that are applied to the workstation and that are also propagated to the underlying Compute Engine resources. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1972
1973
1974
# File 'lib/google/apis/workstations_v1/classes.rb', line 1972

def labels
  @labels
end

#nameString

Identifier. Full name of this workstation. Corresponds to the JSON property name

Returns:

  • (String)


1977
1978
1979
# File 'lib/google/apis/workstations_v1/classes.rb', line 1977

def name
  @name
end

#persistent_directoriesArray<Google::Apis::WorkstationsV1::WorkstationPersistentDirectory>

Optional. Directories to persist across workstation sessions. Corresponds to the JSON property persistentDirectories



1982
1983
1984
# File 'lib/google/apis/workstations_v1/classes.rb', line 1982

def persistent_directories
  @persistent_directories
end

#reconcilingBoolean Also known as: reconciling?

Output only. Indicates whether this workstation is currently being updated to match its intended state. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


1988
1989
1990
# File 'lib/google/apis/workstations_v1/classes.rb', line 1988

def reconciling
  @reconciling
end

#runtime_hostGoogle::Apis::WorkstationsV1::RuntimeHost

Runtime host for the workstation. Corresponds to the JSON property runtimeHost



1994
1995
1996
# File 'lib/google/apis/workstations_v1/classes.rb', line 1994

def runtime_host
  @runtime_host
end

#source_workstationString

Optional. The source workstation from which this workstation's persistent directories were cloned on creation. Corresponds to the JSON property sourceWorkstation

Returns:

  • (String)


2000
2001
2002
# File 'lib/google/apis/workstations_v1/classes.rb', line 2000

def source_workstation
  @source_workstation
end

#start_timeString

Output only. Time when this workstation was most recently successfully started, regardless of the workstation's initial state. Corresponds to the JSON property startTime

Returns:

  • (String)


2006
2007
2008
# File 'lib/google/apis/workstations_v1/classes.rb', line 2006

def start_time
  @start_time
end

#stateString

Output only. Current state of the workstation. Corresponds to the JSON property state

Returns:

  • (String)


2011
2012
2013
# File 'lib/google/apis/workstations_v1/classes.rb', line 2011

def state
  @state
end

#uidString

Output only. A system-assigned unique identifier for this workstation. Corresponds to the JSON property uid

Returns:

  • (String)


2016
2017
2018
# File 'lib/google/apis/workstations_v1/classes.rb', line 2016

def uid
  @uid
end

#update_timeString

Output only. Time when this workstation was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2021
2022
2023
# File 'lib/google/apis/workstations_v1/classes.rb', line 2021

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
# File 'lib/google/apis/workstations_v1/classes.rb', line 2028

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @env = args[:env] if args.key?(:env)
  @etag = args[:etag] if args.key?(:etag)
  @host = args[:host] if args.key?(:host)
  @kms_key = args[:kms_key] if args.key?(:kms_key)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @persistent_directories = args[:persistent_directories] if args.key?(:persistent_directories)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @runtime_host = args[:runtime_host] if args.key?(:runtime_host)
  @source_workstation = args[:source_workstation] if args.key?(:source_workstation)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end