Class: Google::Apis::WorkstationsV1::WorkstationConfig
- Inherits:
-
Object
- Object
- Google::Apis::WorkstationsV1::WorkstationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workstations_v1/classes.rb,
lib/google/apis/workstations_v1/representations.rb,
lib/google/apis/workstations_v1/representations.rb
Overview
A workstation configuration resource in the Cloud Workstations API. Workstation configurations act as templates for workstations. The workstation configuration defines details such as the workstation virtual machine (VM) instance type, persistent storage, container image defining environment, which IDE or Code Editor to use, and more. Administrators and platform teams can also use Identity and Access Management (IAM) rules to grant access to teams or to individual developers.
Instance Attribute Summary collapse
-
#allowed_ports ⇒ Array<Google::Apis::WorkstationsV1::PortRange>
Optional.
-
#annotations ⇒ Hash<String,String>
Optional.
-
#conditions ⇒ Array<Google::Apis::WorkstationsV1::Status>
Output only.
-
#container ⇒ Google::Apis::WorkstationsV1::Container
A Docker container.
-
#create_time ⇒ String
Output only.
-
#degraded ⇒ Boolean
(also: #degraded?)
Output only.
-
#delete_time ⇒ String
Output only.
-
#disable_tcp_connections ⇒ Boolean
(also: #disable_tcp_connections?)
Optional.
-
#display_name ⇒ String
Optional.
-
#enable_audit_agent ⇒ Boolean
(also: #enable_audit_agent?)
Optional.
-
#encryption_key ⇒ Google::Apis::WorkstationsV1::CustomerEncryptionKey
A customer-managed encryption key (CMEK) for the Compute Engine resources of the associated workstation configuration.
-
#ephemeral_directories ⇒ Array<Google::Apis::WorkstationsV1::EphemeralDirectory>
Optional.
-
#etag ⇒ String
Optional.
-
#grant_workstation_admin_role_on_create ⇒ Boolean
(also: #grant_workstation_admin_role_on_create?)
Optional.
-
#host ⇒ Google::Apis::WorkstationsV1::Host
Runtime host for a workstation.
-
#idle_timeout ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#max_usable_workstations ⇒ Fixnum
Optional.
-
#name ⇒ String
Identifier.
-
#persistent_directories ⇒ Array<Google::Apis::WorkstationsV1::PersistentDirectory>
Optional.
-
#readiness_checks ⇒ Array<Google::Apis::WorkstationsV1::ReadinessCheck>
Optional.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#replica_zones ⇒ Array<String>
Optional.
-
#running_timeout ⇒ String
Optional.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkstationConfig
constructor
A new instance of WorkstationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkstationConfig
Returns a new instance of WorkstationConfig.
2432 2433 2434 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2432 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_ports ⇒ Array<Google::Apis::WorkstationsV1::PortRange>
Optional. A list of PortRanges specifying single ports or ranges of ports that
are externally accessible in the workstation. Allowed ports must be one of 22,
80, or within range 1024-65535. If not specified defaults to ports 22, 80, and
ports 1024-65535.
Corresponds to the JSON property allowedPorts
2239 2240 2241 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2239 def allowed_ports @allowed_ports end |
#annotations ⇒ Hash<String,String>
Optional. Client-specified annotations.
Corresponds to the JSON property annotations
2244 2245 2246 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2244 def annotations @annotations end |
#conditions ⇒ Array<Google::Apis::WorkstationsV1::Status>
Output only. Status conditions describing the workstation configuration's
current state.
Corresponds to the JSON property conditions
2250 2251 2252 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2250 def conditions @conditions end |
#container ⇒ Google::Apis::WorkstationsV1::Container
A Docker container.
Corresponds to the JSON property container
2255 2256 2257 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2255 def container @container end |
#create_time ⇒ String
Output only. Time when this workstation configuration was created.
Corresponds to the JSON property createTime
2260 2261 2262 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2260 def create_time @create_time end |
#degraded ⇒ Boolean Also known as: degraded?
Output only. Whether this workstation configuration is in degraded mode, in
which case it may require user action to restore full functionality. The
conditions field contains detailed information about the status of the
configuration.
Corresponds to the JSON property degraded
2268 2269 2270 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2268 def degraded @degraded end |
#delete_time ⇒ String
Output only. Time when this workstation configuration was soft-deleted.
Corresponds to the JSON property deleteTime
2274 2275 2276 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2274 def delete_time @delete_time end |
#disable_tcp_connections ⇒ Boolean Also known as: disable_tcp_connections?
Optional. Disables support for plain TCP connections in the workstation. By
default the service supports TCP connections through a websocket relay.
Setting this option to true disables that relay, which prevents the usage of
services that require plain TCP connections, such as SSH. When enabled, all
communication must occur over HTTPS or WSS.
Corresponds to the JSON property disableTcpConnections
2283 2284 2285 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2283 def disable_tcp_connections @disable_tcp_connections end |
#display_name ⇒ String
Optional. Human-readable name for this workstation configuration.
Corresponds to the JSON property displayName
2289 2290 2291 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2289 def display_name @display_name end |
#enable_audit_agent ⇒ Boolean Also known as: enable_audit_agent?
Optional. Whether to enable Linux auditd logging on the workstation. When
enabled, a service_account must also be specified that has roles/logging.
logWriter and roles/monitoring.metricWriter on the project. Operating
system audit logging is distinct from Cloud Audit Logs and Container output logging.
Operating system audit logs are available in the Cloud Logging console by querying: resource.type="gce_instance"
log_name:"/logs/linux-auditd"
Corresponds to the JSON property enableAuditAgent
2302 2303 2304 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2302 def enable_audit_agent @enable_audit_agent end |
#encryption_key ⇒ Google::Apis::WorkstationsV1::CustomerEncryptionKey
A customer-managed encryption key (CMEK) for the Compute Engine resources of
the associated workstation configuration. Specify the name of your Cloud KMS
encryption key and the default service account. We recommend that you use a
separate service account and follow Cloud KMS best practices.
Corresponds to the JSON property encryptionKey
2312 2313 2314 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2312 def encryption_key @encryption_key end |
#ephemeral_directories ⇒ Array<Google::Apis::WorkstationsV1::EphemeralDirectory>
Optional. Ephemeral directories which won't persist across workstation
sessions.
Corresponds to the JSON property ephemeralDirectories
2318 2319 2320 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2318 def ephemeral_directories @ephemeral_directories end |
#etag ⇒ String
Optional. Checksum computed by the server. May be sent on update and delete
requests to make sure that the client has an up-to-date value before
proceeding.
Corresponds to the JSON property etag
2325 2326 2327 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2325 def etag @etag end |
#grant_workstation_admin_role_on_create ⇒ Boolean Also known as: grant_workstation_admin_role_on_create?
Optional. Grant creator of a workstation roles/workstations.policyAdmin role
along with roles/workstations.user role on the workstation created by them.
This allows workstation users to share access to either their entire
workstation, or individual ports. Defaults to false.
Corresponds to the JSON property grantWorkstationAdminRoleOnCreate
2333 2334 2335 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2333 def grant_workstation_admin_role_on_create @grant_workstation_admin_role_on_create end |
#host ⇒ Google::Apis::WorkstationsV1::Host
Runtime host for a workstation.
Corresponds to the JSON property host
2339 2340 2341 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2339 def host @host end |
#idle_timeout ⇒ String
Optional. Number of seconds to wait before automatically stopping a
workstation after it last received user traffic. A value of "0s" indicates
that Cloud Workstations VMs created with this configuration should never time
out due to idleness. Provide duration terminated by s for seconds—
for example, "7200s" (2 hours). The default is "1200s" (20 minutes).
Corresponds to the JSON property idleTimeout
2349 2350 2351 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2349 def idle_timeout @idle_timeout end |
#labels ⇒ Hash<String,String>
Optional. Labels
that are applied to the workstation configuration and that are also propagated
to the underlying Compute Engine resources.
Corresponds to the JSON property labels
2356 2357 2358 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2356 def labels @labels end |
#max_usable_workstations ⇒ Fixnum
Optional. Maximum number of workstations under this configuration a user can
have workstations.workstation.use permission on. Only enforced on
CreateWorkstation API calls on the user issuing the API request. Can be
overridden by: - granting a user workstations.workstationConfigs.
exemptMaxUsableWorkstationLimit permission, or - having a user with that
permission create a workstation and granting another user workstations.
workstation.use permission on that workstation. If not specified, defaults to
0, which indicates unlimited.
Corresponds to the JSON property maxUsableWorkstations
2368 2369 2370 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2368 def max_usable_workstations @max_usable_workstations end |
#name ⇒ String
Identifier. Full name of this workstation configuration.
Corresponds to the JSON property name
2373 2374 2375 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2373 def name @name end |
#persistent_directories ⇒ Array<Google::Apis::WorkstationsV1::PersistentDirectory>
Optional. Directories to persist across workstation sessions.
Corresponds to the JSON property persistentDirectories
2378 2379 2380 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2378 def persistent_directories @persistent_directories end |
#readiness_checks ⇒ Array<Google::Apis::WorkstationsV1::ReadinessCheck>
Optional. Readiness checks to perform when starting a workstation using this
workstation configuration. Mark a workstation as running only after all
specified readiness checks return 200 status codes.
Corresponds to the JSON property readinessChecks
2385 2386 2387 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2385 def readiness_checks @readiness_checks end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Indicates whether this workstation configuration is currently
being updated to match its intended state.
Corresponds to the JSON property reconciling
2391 2392 2393 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2391 def reconciling @reconciling end |
#replica_zones ⇒ Array<String>
Optional. Immutable. Specifies the zones used to replicate the VM and disk
resources within the region. If set, exactly two zones within the workstation
cluster's region must be specified—for example, ['us-central1-a', 'us-
central1-f']. If this field is empty, two default zones within the region are
used. Immutable after the workstation configuration is created.
Corresponds to the JSON property replicaZones
2401 2402 2403 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2401 def replica_zones @replica_zones end |
#running_timeout ⇒ String
Optional. Number of seconds to wait before automatically stopping a
workstation. We recommend that workstations be stopped daily so that security
updates can be applied upon restart. The idle_timeout and running_timeout
fields are independent of each other. Note that the running_timeout field
stops workstations after the specified time, regardless of whether or not the
workstations are idle. Provide duration terminated by s for seconds—for
example, "54000s" (15 hours). Defaults to "43200s" (12 hours). A value of
"0s" indicates that workstations using this configuration should never time
out. If encryption_key is set, it must be greater than "0s" and less than "
86400s" (24 hours). Warning: A value of "0s" indicates that Cloud
Workstations VMs created with this configuration have no maximum running time.
This is strongly discouraged because you incur costs and will not pick up
security updates.
Corresponds to the JSON property runningTimeout
2418 2419 2420 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2418 def running_timeout @running_timeout end |
#uid ⇒ String
Output only. A system-assigned unique identifier for this workstation
configuration.
Corresponds to the JSON property uid
2424 2425 2426 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2424 def uid @uid end |
#update_time ⇒ String
Output only. Time when this workstation configuration was most recently
updated.
Corresponds to the JSON property updateTime
2430 2431 2432 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2430 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2437 def update!(**args) @allowed_ports = args[:allowed_ports] if args.key?(:allowed_ports) @annotations = args[:annotations] if args.key?(:annotations) @conditions = args[:conditions] if args.key?(:conditions) @container = args[:container] if args.key?(:container) @create_time = args[:create_time] if args.key?(:create_time) @degraded = args[:degraded] if args.key?(:degraded) @delete_time = args[:delete_time] if args.key?(:delete_time) @disable_tcp_connections = args[:disable_tcp_connections] if args.key?(:disable_tcp_connections) @display_name = args[:display_name] if args.key?(:display_name) @enable_audit_agent = args[:enable_audit_agent] if args.key?(:enable_audit_agent) @encryption_key = args[:encryption_key] if args.key?(:encryption_key) @ephemeral_directories = args[:ephemeral_directories] if args.key?(:ephemeral_directories) @etag = args[:etag] if args.key?(:etag) @grant_workstation_admin_role_on_create = args[:grant_workstation_admin_role_on_create] if args.key?(:grant_workstation_admin_role_on_create) @host = args[:host] if args.key?(:host) @idle_timeout = args[:idle_timeout] if args.key?(:idle_timeout) @labels = args[:labels] if args.key?(:labels) @max_usable_workstations = args[:max_usable_workstations] if args.key?(:max_usable_workstations) @name = args[:name] if args.key?(:name) @persistent_directories = args[:persistent_directories] if args.key?(:persistent_directories) @readiness_checks = args[:readiness_checks] if args.key?(:readiness_checks) @reconciling = args[:reconciling] if args.key?(:reconciling) @replica_zones = args[:replica_zones] if args.key?(:replica_zones) @running_timeout = args[:running_timeout] if args.key?(:running_timeout) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |