Class: Google::Apis::WorkstationsV1::WorkstationConfig
- Inherits:
-
Object
- Object
- Google::Apis::WorkstationsV1::WorkstationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/workstations_v1/classes.rb,
lib/google/apis/workstations_v1/representations.rb,
lib/google/apis/workstations_v1/representations.rb
Overview
A workstation configuration resource in the Cloud Workstations API. Workstation configurations act as templates for workstations. The workstation configuration defines details such as the workstation virtual machine (VM) instance type, persistent storage, container image defining environment, which IDE or Code Editor to use, and more. Administrators and platform teams can also use Identity and Access Management (IAM) rules to grant access to teams or to individual developers.
Instance Attribute Summary collapse
-
#allowed_ports ⇒ Array<Google::Apis::WorkstationsV1::PortRange>
Optional.
-
#annotations ⇒ Hash<String,String>
Optional.
-
#conditions ⇒ Array<Google::Apis::WorkstationsV1::Status>
Output only.
-
#container ⇒ Google::Apis::WorkstationsV1::Container
A Docker container.
-
#create_time ⇒ String
Output only.
-
#degraded ⇒ Boolean
(also: #degraded?)
Output only.
-
#delete_time ⇒ String
Output only.
-
#disable_tcp_connections ⇒ Boolean
(also: #disable_tcp_connections?)
Optional.
-
#display_name ⇒ String
Optional.
-
#enable_audit_agent ⇒ Boolean
(also: #enable_audit_agent?)
Optional.
-
#encryption_key ⇒ Google::Apis::WorkstationsV1::CustomerEncryptionKey
A customer-managed encryption key (CMEK) for the Compute Engine resources of the associated workstation configuration.
-
#ephemeral_directories ⇒ Array<Google::Apis::WorkstationsV1::EphemeralDirectory>
Optional.
-
#etag ⇒ String
Optional.
-
#grant_workstation_admin_role_on_create ⇒ Boolean
(also: #grant_workstation_admin_role_on_create?)
Optional.
-
#host ⇒ Google::Apis::WorkstationsV1::Host
Runtime host for a workstation.
-
#idle_timeout ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#max_usable_workstations ⇒ Fixnum
Optional.
-
#name ⇒ String
Identifier.
-
#persistent_directories ⇒ Array<Google::Apis::WorkstationsV1::PersistentDirectory>
Optional.
-
#readiness_checks ⇒ Array<Google::Apis::WorkstationsV1::ReadinessCheck>
Optional.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#replica_zones ⇒ Array<String>
Optional.
-
#running_timeout ⇒ String
Optional.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkstationConfig
constructor
A new instance of WorkstationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkstationConfig
Returns a new instance of WorkstationConfig.
2399 2400 2401 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2399 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_ports ⇒ Array<Google::Apis::WorkstationsV1::PortRange>
Optional. A list of PortRanges specifying single ports or ranges of ports that
are externally accessible in the workstation. Allowed ports must be one of 22,
80, or within range 1024-65535. If not specified defaults to ports 22, 80, and
ports 1024-65535.
Corresponds to the JSON property allowedPorts
2205 2206 2207 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2205 def allowed_ports @allowed_ports end |
#annotations ⇒ Hash<String,String>
Optional. Client-specified annotations.
Corresponds to the JSON property annotations
2210 2211 2212 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2210 def annotations @annotations end |
#conditions ⇒ Array<Google::Apis::WorkstationsV1::Status>
Output only. Status conditions describing the workstation configuration's
current state.
Corresponds to the JSON property conditions
2216 2217 2218 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2216 def conditions @conditions end |
#container ⇒ Google::Apis::WorkstationsV1::Container
A Docker container.
Corresponds to the JSON property container
2221 2222 2223 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2221 def container @container end |
#create_time ⇒ String
Output only. Time when this workstation configuration was created.
Corresponds to the JSON property createTime
2226 2227 2228 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2226 def create_time @create_time end |
#degraded ⇒ Boolean Also known as: degraded?
Output only. Whether this workstation configuration is in degraded mode, in
which case it may require user action to restore full functionality. The
conditions field contains detailed information about the status of the
configuration.
Corresponds to the JSON property degraded
2234 2235 2236 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2234 def degraded @degraded end |
#delete_time ⇒ String
Output only. Time when this workstation configuration was soft-deleted.
Corresponds to the JSON property deleteTime
2240 2241 2242 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2240 def delete_time @delete_time end |
#disable_tcp_connections ⇒ Boolean Also known as: disable_tcp_connections?
Optional. Disables support for plain TCP connections in the workstation. By
default the service supports TCP connections through a websocket relay.
Setting this option to true disables that relay, which prevents the usage of
services that require plain TCP connections, such as SSH. When enabled, all
communication must occur over HTTPS or WSS.
Corresponds to the JSON property disableTcpConnections
2249 2250 2251 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2249 def disable_tcp_connections @disable_tcp_connections end |
#display_name ⇒ String
Optional. Human-readable name for this workstation configuration.
Corresponds to the JSON property displayName
2255 2256 2257 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2255 def display_name @display_name end |
#enable_audit_agent ⇒ Boolean Also known as: enable_audit_agent?
Optional. Whether to enable Linux auditd logging on the workstation. When
enabled, a service_account must also be specified that has roles/logging.
logWriter and roles/monitoring.metricWriter on the project. Operating
system audit logging is distinct from Cloud Audit Logs and Container output logging.
Operating system audit logs are available in the Cloud Logging console by querying: resource.type="gce_instance"
log_name:"/logs/linux-auditd"
Corresponds to the JSON property enableAuditAgent
2268 2269 2270 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2268 def enable_audit_agent @enable_audit_agent end |
#encryption_key ⇒ Google::Apis::WorkstationsV1::CustomerEncryptionKey
A customer-managed encryption key (CMEK) for the Compute Engine resources of
the associated workstation configuration. Specify the name of your Cloud KMS
encryption key and the default service account. We recommend that you use a
separate service account and follow Cloud KMS best practices.
Corresponds to the JSON property encryptionKey
2278 2279 2280 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2278 def encryption_key @encryption_key end |
#ephemeral_directories ⇒ Array<Google::Apis::WorkstationsV1::EphemeralDirectory>
Optional. Ephemeral directories which won't persist across workstation
sessions.
Corresponds to the JSON property ephemeralDirectories
2284 2285 2286 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2284 def ephemeral_directories @ephemeral_directories end |
#etag ⇒ String
Optional. Checksum computed by the server. May be sent on update and delete
requests to make sure that the client has an up-to-date value before
proceeding.
Corresponds to the JSON property etag
2291 2292 2293 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2291 def etag @etag end |
#grant_workstation_admin_role_on_create ⇒ Boolean Also known as: grant_workstation_admin_role_on_create?
Optional. Grant creator of a workstation roles/workstations.policyAdmin role
along with roles/workstations.user role on the workstation created by them.
This allows workstation users to share access to either their entire
workstation, or individual ports. Defaults to false.
Corresponds to the JSON property grantWorkstationAdminRoleOnCreate
2299 2300 2301 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2299 def grant_workstation_admin_role_on_create @grant_workstation_admin_role_on_create end |
#host ⇒ Google::Apis::WorkstationsV1::Host
Runtime host for a workstation.
Corresponds to the JSON property host
2305 2306 2307 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2305 def host @host end |
#idle_timeout ⇒ String
Optional. Number of seconds to wait before automatically stopping a
workstation after it last received user traffic. A value of "0s" indicates
that Cloud Workstations VMs created with this configuration should never time
out due to idleness. Provide duration terminated by s for seconds—
for example, "7200s" (2 hours). The default is "1200s" (20 minutes).
Corresponds to the JSON property idleTimeout
2315 2316 2317 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2315 def idle_timeout @idle_timeout end |
#labels ⇒ Hash<String,String>
Optional. Labels
that are applied to the workstation configuration and that are also propagated
to the underlying Compute Engine resources.
Corresponds to the JSON property labels
2322 2323 2324 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2322 def labels @labels end |
#max_usable_workstations ⇒ Fixnum
Optional. Maximum number of workstations under this configuration a user can
have workstations.workstation.use permission on. Only enforced on
CreateWorkstation API calls on the user issuing the API request. Can be
overridden by: - granting a user workstations.workstationConfigs.
exemptMaxUsableWorkstationLimit permission, or - having a user with that
permission create a workstation and granting another user workstations.
workstation.use permission on that workstation. If not specified, defaults to
0, which indicates unlimited.
Corresponds to the JSON property maxUsableWorkstations
2334 2335 2336 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2334 def max_usable_workstations @max_usable_workstations end |
#name ⇒ String
Identifier. Full name of this workstation configuration.
Corresponds to the JSON property name
2339 2340 2341 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2339 def name @name end |
#persistent_directories ⇒ Array<Google::Apis::WorkstationsV1::PersistentDirectory>
Optional. Directories to persist across workstation sessions.
Corresponds to the JSON property persistentDirectories
2344 2345 2346 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2344 def persistent_directories @persistent_directories end |
#readiness_checks ⇒ Array<Google::Apis::WorkstationsV1::ReadinessCheck>
Optional. Readiness checks to perform when starting a workstation using this
workstation configuration. Mark a workstation as running only after all
specified readiness checks return 200 status codes.
Corresponds to the JSON property readinessChecks
2351 2352 2353 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2351 def readiness_checks @readiness_checks end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Indicates whether this workstation configuration is currently
being updated to match its intended state.
Corresponds to the JSON property reconciling
2357 2358 2359 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2357 def reconciling @reconciling end |
#replica_zones ⇒ Array<String>
Optional. Immutable. Specifies the zones used to replicate the VM and disk
resources within the region. If set, exactly two zones within the workstation
cluster's region must be specified—for example, ['us-central1-a', 'us-
central1-f']. If this field is empty, two default zones within the region are
used. Immutable after the workstation configuration is created.
Corresponds to the JSON property replicaZones
2367 2368 2369 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2367 def replica_zones @replica_zones end |
#running_timeout ⇒ String
Optional. Number of seconds that a workstation can run until it is
automatically shut down. This field applies to workstations in both
STATE_RUNNING and STATE_SUSPENDED. We recommend that workstations be shut down
daily to reduce costs and so that security updates can be applied upon restart.
The idle_timeout and running_timeout fields are independent of each other.
Note that the running_timeout field shuts down VMs after the specified time,
regardless of whether or not the VMs are idle. Provide duration terminated by
s for seconds—for example, "54000s" (15 hours). Defaults to "43200s" (12
hours). A value of "0s" indicates that workstations using this configuration
should never time out. If encryption_key is set, it must be greater than "0s"
and less than "86400s" (24 hours). Warning: A value of "0s" indicates
that Cloud Workstations VMs created with this configuration have no maximum
running time. This is strongly discouraged because you incur costs and will
not pick up security updates.
Corresponds to the JSON property runningTimeout
2385 2386 2387 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2385 def running_timeout @running_timeout end |
#uid ⇒ String
Output only. A system-assigned unique identifier for this workstation
configuration.
Corresponds to the JSON property uid
2391 2392 2393 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2391 def uid @uid end |
#update_time ⇒ String
Output only. Time when this workstation configuration was most recently
updated.
Corresponds to the JSON property updateTime
2397 2398 2399 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2397 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 |
# File 'lib/google/apis/workstations_v1/classes.rb', line 2404 def update!(**args) @allowed_ports = args[:allowed_ports] if args.key?(:allowed_ports) @annotations = args[:annotations] if args.key?(:annotations) @conditions = args[:conditions] if args.key?(:conditions) @container = args[:container] if args.key?(:container) @create_time = args[:create_time] if args.key?(:create_time) @degraded = args[:degraded] if args.key?(:degraded) @delete_time = args[:delete_time] if args.key?(:delete_time) @disable_tcp_connections = args[:disable_tcp_connections] if args.key?(:disable_tcp_connections) @display_name = args[:display_name] if args.key?(:display_name) @enable_audit_agent = args[:enable_audit_agent] if args.key?(:enable_audit_agent) @encryption_key = args[:encryption_key] if args.key?(:encryption_key) @ephemeral_directories = args[:ephemeral_directories] if args.key?(:ephemeral_directories) @etag = args[:etag] if args.key?(:etag) @grant_workstation_admin_role_on_create = args[:grant_workstation_admin_role_on_create] if args.key?(:grant_workstation_admin_role_on_create) @host = args[:host] if args.key?(:host) @idle_timeout = args[:idle_timeout] if args.key?(:idle_timeout) @labels = args[:labels] if args.key?(:labels) @max_usable_workstations = args[:max_usable_workstations] if args.key?(:max_usable_workstations) @name = args[:name] if args.key?(:name) @persistent_directories = args[:persistent_directories] if args.key?(:persistent_directories) @readiness_checks = args[:readiness_checks] if args.key?(:readiness_checks) @reconciling = args[:reconciling] if args.key?(:reconciling) @replica_zones = args[:replica_zones] if args.key?(:replica_zones) @running_timeout = args[:running_timeout] if args.key?(:running_timeout) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |