Class: Google::Apis::WorkstationsV1::WorkstationPersistentDirectory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/workstations_v1/classes.rb,
lib/google/apis/workstations_v1/representations.rb,
lib/google/apis/workstations_v1/representations.rb

Overview

A directory to persist across workstation sessions. Updates to this field will only take effect on this workstation after it is restarted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkstationPersistentDirectory

Returns a new instance of WorkstationPersistentDirectory.



2479
2480
2481
# File 'lib/google/apis/workstations_v1/classes.rb', line 2479

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mount_pathString

Optional. The mount path of the persistent directory. Corresponds to the JSON property mountPath

Returns:

  • (String)


2471
2472
2473
# File 'lib/google/apis/workstations_v1/classes.rb', line 2471

def mount_path
  @mount_path
end

#size_gbFixnum

Optional. Size of the persistent directory in GB. If specified in an update request, this is the desired size of the directory. Corresponds to the JSON property sizeGb

Returns:

  • (Fixnum)


2477
2478
2479
# File 'lib/google/apis/workstations_v1/classes.rb', line 2477

def size_gb
  @size_gb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2484
2485
2486
2487
# File 'lib/google/apis/workstations_v1/classes.rb', line 2484

def update!(**args)
  @mount_path = args[:mount_path] if args.key?(:mount_path)
  @size_gb = args[:size_gb] if args.key?(:size_gb)
end